DfsEvent

Enum DfsEvent 

pub enum DfsEvent {
    Discover {
        vid: VertexId,
        dist: usize,
    },
    Finish {
        vid: VertexId,
        dist: usize,
    },
}
An event reported to a depth-first search visitor (Graph::dfs_with).

igraph has two DFS callbacks: one when a vertex is discovered (in_callback) and one when its subtree is finished (out_callback). A single Rust closure receives both, as the two variants of this enum.

Variants



Discover

A vertex has just been discovered (pre-order).

Fields

vid: VertexId

The discovered vertex.

dist: usize

Its distance (depth) from the root of its search tree.



Finish

The whole subtree of a vertex has been explored (post-order).

Fields

vid: VertexId

The finished vertex.

dist: usize

Its distance (depth) from the root of its search tree: the same value as in the matching Discover event (the raw C callback receives one less).

Implementations

Source

impl DfsEvent

pub fn vid(&self) -> VertexId

The vertex the event is about.

pub fn dist(&self) -> usize

The depth of the vertex in its search tree.