pub struct BfsVisit {
pub vid: VertexId,
pub pred: Option<VertexId>,
pub succ: Option<VertexId>,
pub rank: usize,
pub dist: usize,
}Expand description
What a breadth-first search visitor sees each time a vertex is visited
(the arguments of igraph’s igraph_bfshandler_t).
Fields
vid: VertexIdThe vertex being visited.
pred: Option<VertexId>The vertex visited just before, or None if vid is the root of a
search tree.
succ: Option<VertexId>The vertex that will be visited next, or None if vid is the last
vertex of its search tree.
rank: usizeThe rank of vid, i.e. its position in the visiting order (from 0).
dist: usizeThe distance (number of hops) of vid from the root of its search
tree.