pub enum DfsEvent {
Discover {
vid: VertexId,
dist: usize,
},
Finish {
vid: VertexId,
dist: usize,
},
}Expand description
An event reported to a depth-first search visitor (Graph::dfs_with).
igraph has two DFS callbacks: one when a vertex is discovered
(in_callback) and one when its subtree is finished (out_callback).
A single Rust closure receives both, as the two variants of this enum.
Variants
Discover
A vertex has just been discovered (pre-order).
Fields
Finish
The whole subtree of a vertex has been explored (post-order).
Implementations