pub struct DfsOptions {
pub mode: NeighborMode,
pub unreachable: bool,
}Expand description
Parameters of a depth-first search (Graph::dfs, Graph::dfs_with).
The defaults are: follow out-edges (NeighborMode::Out) and do not
visit vertices unreachable from the root.
use igraph::prelude::*;
use igraph::visitor::DfsOptions;
// 0 -> 1, 2 -> 1: walking against the edges from 1 finds 0 and 2.
let g = Graph::from_edges(&[(0, 1), (2, 1)], 3, true)?;
let opts = DfsOptions::default().with_mode(NeighborMode::In);
assert_eq!(g.dfs(1, &opts)?.order, [1, 0, 2]);
assert_eq!(g.dfs(1, &DfsOptions::default())?.order, [1]);Fields
mode: NeighborModeWhich edges to follow in directed graphs (see BfsOptions::mode).
Ignored for undirected graphs.
unreachable: boolIf true, once the tree of the root is complete, further searches are
started from the not yet visited vertices, in increasing id order.
Implementations
Sourceimpl DfsOptions
impl DfsOptions
Sourcepub fn with_mode(self, mode: NeighborMode) -> Self
pub fn with_mode(self, mode: NeighborMode) -> Self
Sets mode.
Sourcepub fn with_unreachable(self, unreachable: bool) -> Self
pub fn with_unreachable(self, unreachable: bool) -> Self
Sets unreachable.